@@ -65,27 +65,31 @@ class Framework:
         commands = self.__context.get_commands()
         if len(args) == 0:
             logging.error("no command specified! valid commands: {}".format(list(commands.keys())))
-            exit(EXIT_CODE_RUN_ARGUMENTS_ERROR)
+            return EXIT_CODE_RUN_ARGUMENTS_ERROR
         command_name = args[0]
         command_args = args[1:]
         command = commands.get(command_name)
         if command is None:
             logging.error("command {} not found! valid commands: {}".format(command_name, list(commands.keys())))
-            exit(EXIT_CODE_RUN_ARGUMENTS_ERROR)
+            return EXIT_CODE_RUN_ARGUMENTS_ERROR
         try:
             output, err = command.run(command_args)
         except Exception as e:
             logging.debug("failed to run command {}".format(command_args), exc_info=e)
             err = e
+        except SystemExit as exit_code:
+            logging.debug("failed to run command {}, exit_code={}".format(command_args, exit_code))
+            return EXIT_CODE_UNKNOWN
         if err is not None:
             logging.error("failed to run command {}, error message: {}".format(command_args, str(err)))
-            exit(EXIT_CODE_RUN_ARGUMENTS_ERROR if isinstance(err, error.ArgumentsError)
-                 else EXIT_CODE_CONF_ERROR if isinstance(err, error.ConfError) else EXIT_CODE_UNKNOWN)
+            return EXIT_CODE_RUN_ARGUMENTS_ERROR if isinstance(err, error.ArgumentsError) else\
+                EXIT_CODE_CONF_ERROR if isinstance(err, error.ConfError) else EXIT_CODE_UNKNOWN
         if isinstance(output, str):
             print(output)
         elif isinstance(output, list):
             for index, item in enumerate(output):
                 print(item)
+        return EXIT_CODE_NORMAL
 
 
 def init_logging(executing_path, log_conf_file, log_file_path):
